pub trait Zeroize {
// Required method
fn zeroize(&mut self);
}Expand description
Overwrite the initialized representation of a value with its zero value.
This deliberately makes no claim about inaccessible allocator capacity. Secret containers in dcrypt use exact-size boxed slices so every initialized byte can be cleared using safe Rust.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".